@@ -7,8 +7,10 @@ test_that("Checksums read and written correctly", {
   expect_true(all(file.copy(sampleFiles, tmpdir)))
 
   csf <- file.path(tmpdir, "CHECKSUMS.txt")
-  cnamesR <- c("result", "expectedFile", "actualFile", "checksum.x", "checksum.y",
-               "algorithm.x", "algorithm.y", "filesize.x", "filesize.y")
+  cnamesR <- c(
+    "result", "expectedFile", "actualFile", "checksum.x", "checksum.y",
+    "algorithm.x", "algorithm.y", "filesize.x", "filesize.y"
+  )
   cnamesW <- c("file", "checksum", "filesize", "algorithm")
 
   # 1. read Checksums without CHECKSUMS.txt file
@@ -35,9 +37,9 @@ test_that("Checksums read and written correctly", {
   expect_true(all(colnames(txt) == cnamesR))
   expect_equal(nrow(txt), NROW(dir(tmpdir, pattern = "[.]R$")))
 
-   #expect_identical(sort(txt$expectedFile), sort(basename(sampleFiles)))
-  #expect_true(all(sort(txt$expectedFile) == sort(basename(sampleFiles))))
-  a <- basename2(sort(grep("\\.R$", txt[result == "OK",]$expectedFile, value = TRUE))) # the [result == "OK",] is because some unknown reason on GA
+  # expect_identical(sort(txt$expectedFile), sort(basename(sampleFiles)))
+  # expect_true(all(sort(txt$expectedFile) == sort(basename(sampleFiles))))
+  a <- basename2(sort(grep("\\.R$", txt[result == "OK", ]$expectedFile, value = TRUE))) # the [result == "OK",] is because some unknown reason on GA
   b <- sort(basename2(sampleFiles))
   expect_identical(a, b)
   # expect_identical(a[1], b[1])
@@ -48,10 +50,12 @@ test_that("Checksums read and written correctly", {
   # expect_identical(a[6], b[6])
 
   # 4. read Checksums with non-empty, but incomplete CHECKSUMS.txt file
-  out <- txt[, `:=`(file = expectedFile,
-                       checksum = checksum.x,
-                       algorithm = algorithm.x)][1:4]
-  #out <- data.table::data.table(file = basename(sampleFiles[-1]),
+  out <- txt[, `:=`(
+    file = expectedFile,
+    checksum = checksum.x,
+    algorithm = algorithm.x
+  )][1:4]
+  # out <- data.table::data.table(file = basename(sampleFiles[-1]),
   #                  checksum = csums[-1],
   #                  algorithm = c("xxhash64", "xxhash64", "xxhash64", "xxhash64"),
   #                  stringsAsFactors = FALSE)
@@ -67,7 +71,7 @@ test_that("Checksums read and written correctly", {
   expect_true(all(colnames(txt) == cnamesR))
   txt <- Checksums(tmpdir, write = TRUE)
   txt <- Checksums(tmpdir)
-  txt <- txt[grepl("[.]R$", expectedFile)][result == "OK",]
+  txt <- txt[grepl("[.]R$", expectedFile)][result == "OK", ]
   expect_equal(nrow(txt), NROW(dir(tmpdir, pattern = "[.]R$")))
   # expect_true(all(sort(txt$expectedFile) == sort(basename(sampleFiles))))
   a <- basename2(sort(grep("\\.R$", txt$expectedFile, value = TRUE)))
