@@ -3,21 +3,28 @@ test_that("test Cache(useCloud=TRUE, ...)", {
   skip_on_ci()
 
   testInit(
-    c("googledrive", "terra"), tmpFileExt = c(".tif", ".grd"),
+    c("googledrive", "terra"),
+    tmpFileExt = c(".tif", ".grd"),
     needGoogleDriveAuth = TRUE,
-    opts = list("reproducible.cachePath" = file.path(tempdir(), rndstr(1, 7)),
-                "reproducible.ask" = FALSE)
+    opts = list(
+      "reproducible.cachePath" = file.path(tempdir(), rndstr(1, 7)),
+      "reproducible.ask" = FALSE
+    )
   )
 
   clearCache(x = tmpCache)
   testsForPkgs <- "testsForPkgs"
-  if (isTRUE(tryCatch(googledrive::drive_ls(testsForPkgs), error = function(e) TRUE)))
+  if (isTRUE(tryCatch(googledrive::drive_ls(testsForPkgs), error = function(e) TRUE))) {
     testsForPkgsDir <- retry(quote(googledrive::drive_mkdir(name = testsForPkgs)))
+  }
   newDir <- retry(quote(googledrive::drive_mkdir(name = rndstr(1, 6), path = testsForPkgs)))
-  cloudFolderID = newDir
-  on.exit({
-    retry(quote(googledrive::drive_rm(cloudFolderID)))
-  }, add = TRUE)
+  cloudFolderID <- newDir
+  on.exit(
+    {
+      retry(quote(googledrive::drive_rm(cloudFolderID)))
+    },
+    add = TRUE
+  )
 
   #######################################
   # local absent, cloud absent
@@ -40,7 +47,7 @@ test_that("test Cache(useCloud=TRUE, ...)", {
   #######################################
   # local absent, cloud present
   #######################################
-  #kkkk <<- 1
+  # kkkk <<- 1
 
   clearCache(userTags = .robustDigest(1), x = tmpCache, useCloud = FALSE)
   mess3 <- capture_messages({
@@ -94,10 +101,11 @@ test_that("test Cache(useCloud=TRUE, ...)", {
   ########
   try(googledrive::drive_rm(newDir), silent = TRUE) # clear the original one
   cloudFolderID <- getOption("reproducible.cloudFolderID")
-  clearCache(x = tmpCache, useCloud = TRUE)#, cloudFolderID = cloudFolderID)
+  clearCache(x = tmpCache, useCloud = TRUE) # , cloudFolderID = cloudFolderID)
   # Add 3 things to cloud and local -- then clear them all
-  for (i in 1:3)
+  for (i in 1:3) {
     a1 <- Cache(rnorm, i, cloudFolderID = cloudFolderID, cachePath = tmpCache, useCloud = TRUE)
+  }
   expect_silent({
     mess1 <- capture_messages(
       clearCache(x = tmpCache, useCloud = TRUE, cloudFolderID = cloudFolderID)
@@ -107,8 +115,9 @@ test_that("test Cache(useCloud=TRUE, ...)", {
   expect_true(NROW(googledrive::drive_ls(path = cloudFolderFromCacheRepo(tmpCache))) == 0)
 
   # Add 3 things to local, only 2 to cloud -- clear them all, without an error
-  for (i in 1:2)
+  for (i in 1:2) {
     a1 <- Cache(rnorm, i, cloudFolderID = cloudFolderID, cachePath = tmpCache, useCloud = TRUE)
+  }
   a1 <- Cache(rnorm, 3, cloudFolderID = cloudFolderID, cachePath = tmpCache, useCloud = FALSE)
   expect_silent({
     mess2 <- capture_messages(
@@ -135,83 +144,100 @@ test_that("test Cache(useCloud=TRUE, ...) with raster-backed objs -- tif and grd
   skip_on_cran()
   skip_on_ci()
   testInit(c("googledrive", "terra"),
-                          # tmpFileExt = c(".tif", ".grd"),
-                          needGoogleDriveAuth = TRUE,
-                          opts = list("reproducible.ask" = FALSE))
+    # tmpFileExt = c(".tif", ".grd"),
+    needGoogleDriveAuth = TRUE,
+    opts = list("reproducible.ask" = FALSE)
+  )
 
   opts <- options("reproducible.cachePath" = tmpdir)
   suppressWarnings(rm(list = "aaa", envir = .GlobalEnv))
 
-  on.exit({
-    retry(quote(googledrive::drive_rm(googledrive::as_id(newDir$id))))
-    options(opts)
-  }, add = TRUE)
+  on.exit(
+    {
+      retry(quote(googledrive::drive_rm(googledrive::as_id(newDir$id))))
+      options(opts)
+    },
+    add = TRUE
+  )
   clearCache(x = tmpCache)
   clearCache(x = tmpdir)
   newDir <- retry(quote(googledrive::drive_mkdir(name = basename2(tmpdir), path = "testsForPkgs")))
-  cloudFolderID = newDir
+  cloudFolderID <- newDir
 
-  testRasterInCloud(".tif", cloudFolderID = cloudFolderID, numRasterFiles = 1, tmpdir = tmpdir,
-                    type = "Raster")
+  testRasterInCloud(".tif",
+    cloudFolderID = cloudFolderID, numRasterFiles = 1, tmpdir = tmpdir,
+    type = "Raster"
+  )
 
   retry(quote(googledrive::drive_rm(googledrive::as_id(newDir$id))))
   clearCache(x = tmpdir)
-  newDir <- retry(quote(googledrive::drive_mkdir(name = rndstr(1,6), path = "testsForPkgs")))
-  cloudFolderID = newDir
+  newDir <- retry(quote(googledrive::drive_mkdir(name = rndstr(1, 6), path = "testsForPkgs")))
+  cloudFolderID <- newDir
 
   # the 3 raster files include the .grd, .gri, and .grd.aux.xml
-  testRasterInCloud(".grd", cloudFolderID = cloudFolderID, numRasterFiles = 3, tmpdir = tmpdir,
-                    type = "Raster")
-
+  testRasterInCloud(".grd",
+    cloudFolderID = cloudFolderID, numRasterFiles = 3, tmpdir = tmpdir,
+    type = "Raster"
+  )
 })
 
 test_that("test Cache(useCloud=TRUE, ...) with raster-backed objs -- stack", {
   skip_on_cran()
   skip_on_ci()
   testInit(c("googledrive", "terra"),
-                          # tmpFileExt = c(".tif", ".grd"),
-                          needGoogleDriveAuth = TRUE,
-                          opts = list("reproducible.ask" = FALSE))
+    # tmpFileExt = c(".tif", ".grd"),
+    needGoogleDriveAuth = TRUE,
+    opts = list("reproducible.ask" = FALSE)
+  )
 
 
   # googledrive::drive_auth("predictiveecology@gmail.com")
-  on.exit({
-    retry(quote(googledrive::drive_rm(googledrive::as_id(newDir$id))))
-    options(opts)
-  }, add = TRUE)
+  on.exit(
+    {
+      retry(quote(googledrive::drive_rm(googledrive::as_id(newDir$id))))
+      options(opts)
+    },
+    add = TRUE
+  )
   opts <- options("reproducible.cachePath" = tmpdir)
   on.exit(options(opts), add = TRUE)
   clearCache(x = tmpCache)
   clearCache(x = tmpdir)
   newDir <- retry(quote(googledrive::drive_mkdir(name = basename2(tmpdir), path = "testsForPkgs")))
-  cloudFolderID = newDir
-
-  testRasterInCloud(".tif", cloudFolderID = cloudFolderID, numRasterFiles = 2, tmpdir = tmpdir,
-                    type = "Stack")
+  cloudFolderID <- newDir
 
+  testRasterInCloud(".tif",
+    cloudFolderID = cloudFolderID, numRasterFiles = 2, tmpdir = tmpdir,
+    type = "Stack"
+  )
 })
 
 test_that("test Cache(useCloud=TRUE, ...) with raster-backed objs -- brick", {
   skip_on_cran()
   skip_on_ci()
   testInit(c("googledrive", "terra"),
-                          needGoogleDriveAuth = TRUE,
-                          opts = list("reproducible.ask" = FALSE))
+    needGoogleDriveAuth = TRUE,
+    opts = list("reproducible.ask" = FALSE)
+  )
 
   opts <- options("reproducible.cachePath" = tmpdir)
   # googledrive::drive_auth("predictiveecology@gmail.com")
-  on.exit({
-    retry(quote(googledrive::drive_rm(googledrive::as_id(newDir$id))))
-    options(opts)
-  }, add = TRUE)
+  on.exit(
+    {
+      retry(quote(googledrive::drive_rm(googledrive::as_id(newDir$id))))
+      options(opts)
+    },
+    add = TRUE
+  )
   clearCache(x = tmpCache)
   clearCache(x = tmpdir)
   newDir <- retry(quote(googledrive::drive_mkdir(name = tempdir2(), path = "testsForPkgs")))
-  cloudFolderID = newDir
-
-  testRasterInCloud(".tif", cloudFolderID = cloudFolderID, numRasterFiles = 1, tmpdir = tmpdir,
-                    type = "Brick")
+  cloudFolderID <- newDir
 
+  testRasterInCloud(".tif",
+    cloudFolderID = cloudFolderID, numRasterFiles = 1, tmpdir = tmpdir,
+    type = "Brick"
+  )
 })
 
 test_that("prepInputs works with team drives", {
@@ -221,8 +247,10 @@ test_that("prepInputs works with team drives", {
   testInit(
     needGoogleDriveAuth = TRUE,
     "googledrive",
-    opts = list("reproducible.cachePath" = file.path(tempdir(), rndstr(1, 7)),
-                "reproducible.ask" = FALSE)
+    opts = list(
+      "reproducible.cachePath" = file.path(tempdir(), rndstr(1, 7)),
+      "reproducible.ask" = FALSE
+    )
   )
 
   # zipUrl <- "https://drive.google.com/file/d/1zRX2c55ebJbQtjijCErEfGxhsa7Ieph2" # Orig
@@ -233,19 +261,25 @@ test_that("prepInputs works with team drives", {
   opts <- options("reproducible.interactiveOnDownloadFail" = FALSE)
   on.exit(options(opts), add = TRUE)
   if (packageVersion("googledrive") < "2.0.0") {
-    wb <- prepInputs(targetFile = "WB_BCR.shp", destinationPath = tmpdir, url = zipUrl,
-                     alsoExtract = "similar",
-                     team_drive = TRUE)
+    wb <- prepInputs(
+      targetFile = "WB_BCR.shp", destinationPath = tmpdir, url = zipUrl,
+      alsoExtract = "similar",
+      team_drive = TRUE
+    )
   } else {
     err <- capture_error(
       noisy <- capture.output(
-      wb <- prepInputs(targetFile = "WB_BCR.shp", destinationPath = tmpdir, url = zipUrl,
-                       alsoExtract = "similar",
-                       shared_drive = TRUE)
-    ))
+        wb <- prepInputs(
+          targetFile = "WB_BCR.shp", destinationPath = tmpdir, url = zipUrl,
+          alsoExtract = "similar",
+          shared_drive = TRUE
+        )
+      )
+    )
     if (is.null(err)) {
-      if (.requireNamespace("sf"))
+      if (.requireNamespace("sf")) {
         expect_true(is(wb, "sf"))
+      }
     }
   }
 })
