@@ -11,10 +11,11 @@ test_that("test parallel collisions", {
   #   which works on Linux, Mac, Windows
   N <- min(2L, parallel::detectCores())
 
-  if (useDBI())
+  if (useDBI()) {
     if (!file.exists(CacheDBFile(tmpdir))) {
       createCache(tmpdir)
     }
+  }
 
   # make function that will write to cache repository from with clusters
   numNew <- 20
@@ -25,10 +26,16 @@ test_that("test parallel collisions", {
       checkPath(dirname(fn), create = TRUE)
     }
     withCallingHandlers(
-      Cache(rnorm, 10, sd = x %% numNew + 1, cachePath = cachePath,
-            verbose = 4), # The "overwrite" means delete, rewrite, delete, rewrite over and over
-      message = function(m) if (keepLog)
-        cat(m$message, file = fn, append = TRUE))
+      Cache(rnorm, 10,
+        sd = x %% numNew + 1, cachePath = cachePath,
+        verbose = 4
+      ), # The "overwrite" means delete, rewrite, delete, rewrite over and over
+      message = function(m) {
+        if (keepLog) {
+          cat(m$message, file = fn, append = TRUE)
+        }
+      }
+    )
   }
   cl <- makeCluster(N)
   on.exit(parallel::stopCluster(cl), add = TRUE)
@@ -44,16 +51,21 @@ test_that("test parallel collisions", {
     library(reproducible)
   })
   numToRun <- 140
-  if (interactive())
+  if (interactive()) {
     print(tmpdir)
+  }
 
   # There is a 'creating Cache at the same time' problem -- haven't resolved
   #  Just make cache first and it seems fine
   clearCache(tmpdir) # If in c:/Eliot, then it may be reused
   Cache(rnorm, 1, cachePath = tmpdir)
-  a <- try(clusterMap(cl = cl, fun, seq(numToRun), numNew = numNew, keepLog = keepLog,
-                      cachePath = tmpdir, .scheduling = "dynamic"),
-           silent = FALSE)
+  a <- try(
+    clusterMap(
+      cl = cl, fun, seq(numToRun), numNew = numNew, keepLog = keepLog,
+      cachePath = tmpdir, .scheduling = "dynamic"
+    ),
+    silent = FALSE
+  )
   if (!is(a, "try-error")) {
     expect_true(is.list(a))
     expect_true(length(a) == numToRun)
@@ -61,6 +73,7 @@ test_that("test parallel collisions", {
     expect_equal(sum(news), numNew)
   }
   endTime <- Sys.time()
-  if (interactive())
+  if (interactive()) {
     print(endTime - startTime)
+  }
 })
